@@ -7,7 +7,10 @@ import typing
 from ast import AST
 from typing import Any, Callable, NamedTuple, Sequence, Union
 
-import astunparse
+try:
+    from ast import unparse as astunparse
+except ImportError:
+    from astunparse import unparse as astunparse  # type: ignore[no-redef]
 
 Node = Union[AST, Sequence[AST]]
 
@@ -20,7 +23,19 @@ class Replacement(NamedTuple):
 
 
 def _is_iterable(value: Any) -> bool:  # type: ignore[misc]
-    """Return whether `value` is a non-string iterable."""
+    """Return whether `value` is a non-string iterable.
+
+    Examples
+    --------
+    >>> _is_iterable(1)
+    False
+    >>> _is_iterable([1])
+    True
+    >>> _is_iterable("a")
+    False
+    >>> _is_iterable(["a"])
+    True
+    """
     return not isinstance(value, str) and isinstance(value, collections.abc.Iterable)
 
 
@@ -38,6 +53,17 @@ def matches(value: Node, pattern: Node) -> bool:
     -------
     bool
         Whether `value` matches `pattern`
+
+    Examples
+    --------
+    >>> import ast
+    >>> node = ast.parse("x = 1")
+    >>> pattern = node
+    >>> matches(node, pattern)
+    True
+    >>> node = ast.parse("x = 2")
+    >>> matches(node, pattern)
+    False
     """
     # types must match exactly
     if type(value) != type(pattern):
@@ -88,7 +114,23 @@ class ASTRewriter:
         return wrapper
 
     def rewrite(self, node: AST) -> AST:
-        """Rewrite `node` if it matches a registered pattern."""
+        """Rewrite `node` if it matches a registered pattern.
+
+        Examples
+        --------
+        >>> rewriter = ASTRewriter()
+        >>> pattern = ast.parse("x = 1")
+        >>> @rewriter.register(pattern)
+        ... def make_it_two(node):
+        ...     return ast.parse("x = 2")
+        ...
+        >>> node = ast.parse("x = 1")
+        >>> print(astunparse(node))  # doctest: +NORMALIZE_WHITESPACE
+        x = 1
+        >>> rewritten = rewriter.rewrite(node)
+        >>> print(astunparse(rewritten))  # doctest: +NORMALIZE_WHITESPACE
+        x = 2
+        """  # noqa: E501
         try:
             return next(
                 func(node) for pattern, func in self.funcs if matches(node, pattern)
@@ -112,7 +154,16 @@ def build_rewrites(proto: str, dep: str) -> list[Replacement]:
     -------
     list[Replacement]
         A list of mapping from old code to new code
-    """
+
+    Examples
+    --------
+    >>> from pprint import pprint
+    >>> proto = "a/b/c"
+    >>> dep = "foo/bar"
+    >>> pprint(build_rewrites(proto, dep))
+    [Replacement(old='from foo import bar_pb2 as foo_dot_bar__pb2', new='from ...foo import bar_pb2 as foo_dot_bar__pb2'),
+     Replacement(old='import foo.bar_pb2', new='from ... import foo')]
+    """  # noqa: E501
     parts = dep.split("/")
 
     *import_parts, part = parts
@@ -179,4 +230,4 @@ class ASTImportRewriter:
         ), f"more than one rewrite rule found for pattern `{replacement.old}`"
 
     def rewrite(self, src: str) -> str:
-        return astunparse.unparse(self.node_transformer.visit(ast.parse(src)))
+        return astunparse(self.node_transformer.visit(ast.parse(src)))
